@@ -291,7 +291,9 @@ class Fs_dialplan_module_class extends Fs_module_class
         // Default implementation - Check object name exists (but check in
         // merged dialplans)
         $objs = $this->dialplans();
-        if($objs[$name]){
+        //Add case-insensitive object name validation
+        $obj_keys = array_keys($objs);
+        if(safe_in_arrayi($name, $obj_keys)){
             $reason = "Already exists";
             return false;
         }
