@@ -43,11 +43,14 @@ class Fs_gateway_class extends Safe_configurable_object_class
         //$this->add_field('user-agent-string', 'User Agent', 'string', '', 50);
         //$this->add_enum_field($name, $label, $type, $default, $enum_array)
         $this->add_field('realm', 'Domain', 'string', '', 50);
-        $this->set_field_rules('realm', 'required|valid_ip_or_domain rule');
+        $this->set_field_rules('realm', 'required|valid_ip_port_domain');
         $this->set_field_help('realm', 'Domain Name (if DNS is supported) or IP address provided by the ITSP');
         $this->add_field('username', 'User Name', 'string', '', 25);
         $this->set_field_rules('username', "required[password]|regex_match[/^([a-z0-9-_.!~*'()&=+$,;?\/])+$/i]");
         $this->set_field_help('username', 'The authentication username to be used in all outgoing INVITE and REGISTER messages in this trunk.');
+        $this->add_field('auth-username', 'Authentication User Name', 'string', '', 25);
+        $this->set_field_rules('auth-username', 'alpha_dash');
+        $this->set_field_help('auth-username', 'If different from the User Name, the authentication username to be used in all outgoing INVITE and REGISTER messages in this trunk. If not provided the User Name will be used.');
         $this->add_field('password', 'Password', 'password', '', 25);
         $this->set_field_rules('password', "required[username]|regex_match[/^([a-z0-9-_.!~*'()&=+$,])+$/i]");
         $this->set_field_help('password', 'The SIP trunk authentication password.');
