@@ -449,6 +449,44 @@ function safe_csv_download($obj_name = '', $data = null)
         $rs = unlink($tmp_path.$name);
     }
 }
+
+function safe_mime_content_type($filename) {
+    $realpath = realpath($filename);
+    $rs = false;
+    if ($realpath
+            && function_exists('finfo_file')
+            && function_exists('finfo_open')
+            && defined('FILEINFO_MIME_TYPE')
+    ){
+        // Use the Fileinfo PECL extension (PHP 5.3+)
+        $rs =  finfo_file( finfo_open( FILEINFO_MIME_TYPE ), $realpath );
+    }
+    if (!$rs && function_exists( 'mime_content_type' ) ) {
+        // Deprecated in PHP 5.3
+        $rs = mime_content_type( $realpath );
+    }
+    if (!$rs){
+        // Try to determine if the filename includes a file extension.
+        // We need it in order to set the MIME type
+        if (false === strpos($filename, '.')) {
+            $rs = 'application/octet-stream';
+        } else {
+            // Grab the file extension
+            $extension = end(explode('.', $filename));
+            // Load the mime types
+            if (defined('ENVIRONMENT') AND is_file(APPPATH . 'config/' . ENVIRONMENT . '/mimes.php')) {
+                include (APPPATH . 'config/' . ENVIRONMENT . '/mimes.php');
+            } elseif (is_file(APPPATH . 'config/mimes.php')) {
+                include (APPPATH . 'config/mimes.php');
+            }
+            // Set a default mime if we can't find it
+            if (isset($mimes[$extension])) {
+                $rs = (is_array($mimes[$extension])) ? $mimes[$extension][0] : $mimes[$extension];
+            }
+        }
+    }
+    return $rs;
+}
 /**
  * Download a file
  *
@@ -488,7 +526,7 @@ function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $m
     // Check for mime
     if (!isset($mime)) {
         if (!isset($buffer)) {
-            $mime = mime_content_type($filename);
+            $mime = safe_mime_content_type($filename);
         }
     }
     if (!isset($mime)) $mime = 'text/plain';
@@ -497,7 +535,7 @@ function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $m
     // error_log ( "Safe_download: $filename:$mime " );
     // Generate the server headers
     if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") !== FALSE) {
-        header('Content-Type: "' . $mime . '"');
+        header('Content-Type: ' . $mime);
         header('Content-Disposition: attachment; filename="' . $user_filename . '"');
         header('Expires: 0');
         header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
@@ -505,7 +543,7 @@ function safe_download($filename = '', $buffer = NULL, $user_filename = NULL, $m
         header('Pragma: public');
         header("Content-Length: " . strlen($data));
     } else {
-        header('Content-Type: "' . $mime . '"');
+        header('Content-Type: ' . $mime);
         header('Content-Disposition: attachment; filename="' . $user_filename . '"');
         header("Content-Transfer-Encoding: binary");
         header('Expires: 0');
@@ -1379,6 +1417,39 @@ function safe_is_hash_password($data){
     return false;
 }
 
+/**
+ * @brief Clear $_SESSION data used for product info caching
+ *
+ * TODO: Ideally all 'cached' session data should be stored in $_SESSION['cache'] 
+ * array entry so we don;t have to maintain a list of cached 'entries'
+ * Doing so will require adding functions like:
+ *   - safe_session_set_cache($entry, $data)
+ *   - safe_session_get_cache($entry)
+ * @return 
+*/
+function safe_session_clear_cache(){
+    // Ensure we clear 'cached' session data, as of writting:
+    // * menu entries -> $_SESSION['pagedata']
+    // * Product definition XML - $_SESSION['prod-def']
+    $_cached_entries = array('pagedata', 'prod-def');
+    session_start();
+    foreach($_cached_entries as $_entry){
+        if(isset($_SESSION[$_entry])){
+            unset($_SESSION[$_entry]);
+        }
+    }
+    session_write_close();
+}
+//case-insensitive in_array()
+function safe_in_arrayi($needle, $haystack) {
+    return in_array(strtolower($needle), array_map('strtolower', $haystack));
+}
 
+function safe_trim($str) {
+    if(is_string($str)){
+        $str = trim($str);
+    }
+    return $str;
+}
 /* End of file safe_helper.php */
             
