@@ -63,7 +63,6 @@ class Safe_application_class extends Safe_service_class
         $this->register_aggregate_object( 'configuration',
             array(
                 'name' => 'Configuration',
-                'pseudo' => true,
                 'description' => array(
                     'Manages overall Application configuration.',
                     ),
@@ -368,11 +367,14 @@ class Safe_application_class extends Safe_service_class
                 'delete',
                 'restore'
             ),
+            'global_methods' => true,
             'methods' => array(
                     'backup' => array(
+                            'scope' => 'global',
                             'name' => 'Backup',
                             'description' => array( 'Backup system settings.' ),
                             'request' => 'POST',
+                            'class' => $this->api_backup_archive_parameters()->get_data(false),
                     ),
                     'download' => array(
                             'name' => 'Download',
@@ -380,6 +382,7 @@ class Safe_application_class extends Safe_service_class
                             'request' => 'GET',
                     ),
                     'upload' => array(
+                            'scope' => 'global',
                             'name' => 'Upload',
                             'description' => array( 'Upload a backup files.' ),
                             'request' => 'POST',
@@ -920,23 +923,29 @@ class Safe_application_class extends Safe_service_class
         $cfg_mgr = $the_product->local_node()->configuration_manager();
         $archive_mgr = $cfg_mgr->archive_manager();
         $reason = array();
-        if ($the_product->can_backup($reason)) {
-            $the_product->pre_backup($name, $reason);
-            // Create archive
-            $archive = $archive_mgr->create_archive($name);
-            // Post backup hook
-            $the_product->post_backup($name, $reason);
-            if (FALSE !== $archive) {
-                return array('name' => $archive);
-            } else {
-                // Display error
-                $output['notif_error'] = 'Fail to create archive';
-                return false;
+        // Validate submitted data
+        $cfg = $this->api_backup_archive_parameters();
+
+        if($cfg->validate($data, $reason)) {
+            $cfg->set_data_values($data);
+            $type = $cfg->get_data_value('backup_type', false);
+            if ($the_product->can_backup($type, $reason)) {
+                $the_product->pre_backup($type, $reason);
+                // Create archive
+                $archive = $archive_mgr->create_archive($type, $name);
+                // Post backup hook
+                $the_product->post_backup($type, $reason);
+                if (FALSE !== $archive) {
+                    return array('name' => $archive);
+                } else {
+                    // Display error
+                    $output = array('Fail to create archive');
+                    return false;
+                }
             }
-        }else{
-            $output['notif_error'] = $reason;
-            return false;
         }
+        $output = $reason;
+        return false;
     }
     public function api_backup_archive_parameters()
     {
@@ -983,11 +992,11 @@ class Safe_application_class extends Safe_service_class
                 || !($rc = $archive_mgr->restore_archive($name)) 
                 || !($rc = $the_product->post_restore($info, $reasons))
                     ) {
-                $output['notif_error'] = $reasons;
+                $output = $reasons;
                 return false;
             }
         }else{
-            $output['notif_error'] = $reasons;
+            $output = $reasons;
             return false;
         }
         return true;
