@@ -819,7 +819,8 @@ class Safe_object_class
     {
         // Default implementation - Check object name exists
         $obj_keys = $this->get_aggregate_objects_keys($type);
-        if(in_array($name, $obj_keys)){
+        //Add case-insensitive object name validation
+        if(safe_in_arrayi($name, $obj_keys)){
             $reason = "Already exists";
             return false;
         }else{
@@ -1781,6 +1782,12 @@ class Safe_configurable_object_class extends Safe_serializable_object_class
                 // Need to create field
                 
             } else {
+                //remove the white space
+                if(is_array($v)){
+                    $v = array_map('safe_trim',$v);
+                }else{
+                    $v = safe_trim($v);
+                }
                 // Update the field value or default
                 if (isset($this->_fields[$k]['value'])) {
                     if('' == $v){
