@@ -518,7 +518,9 @@ class Safe_centos_wrapper extends Safe_os_wrapper
                 $prev_stats = $_SESSION['system']['stats'];
             }
             // Store stats for next round
+            session_start();
             $_SESSION['system']['stats'] = $curr_stats;
+            session_write_close();
             // Compute difference since last run
             $_total = $curr_stats['total'] - $prev_stats['total'];
             foreach($curr_stats as $k=>$v){
@@ -539,7 +541,9 @@ class Safe_centos_wrapper extends Safe_os_wrapper
         if($rc){
             $cpu_count = intval($output[0]);
         }
+        session_start();
         $_SESSION['system']['cpu']['count'] = $cpu_count;
+        session_write_close();
         return $cpu_count;
     }
     public function version()
