@@ -30,18 +30,23 @@ function &Safe_get_product()
         * Retrieve product from prod-def.xml
         */
 
-        $dom = new DOMDocument();
-        $dom->load(SNG_PRODUCT_DEF);
-        $dom->xinclude();
+        if(!isset($_SESSION['prod_def'])){
+            $dom = new DOMDocument();
+            $dom->load(SNG_PRODUCT_DEF);
+            $dom->xinclude();
 
-        $xml = simplexml_import_dom($dom);
-        // Get only the product
-        $xml = $xml->xpath('//product');
-        $tmp_def = json_decode(json_encode($xml) , true);
-        $prod_def = array('product' => $tmp_def[0]);
+            $xml = simplexml_import_dom($dom);
+            // Get only the product
+            $xml = $xml->xpath('//product');
+            $tmp_def = json_decode(json_encode($xml) , true);
+            session_start();
+            $_SESSION['prod_def'] = array('product' => $tmp_def[0]);
+            session_write_close();
 
-        unset($xml);
-        unset($tmp_def);
+            unset($xml);
+            unset($tmp_def);
+        }
+        $prod_def = $_SESSION['prod_def'];
 
         // Try to locate the product specific class
         $product_name = strtolower($prod_def['product']['@attributes']['name']);
