@@ -507,6 +507,7 @@ function safe_confirmation_box(title, content, url_ok, url_cancel, ok_method, ca
  * @param url ( URL to redirect user to after timeout expired when user press the redirect button - default is proper $_SERVER array entry containing base url + port ) 
  * @desc When the timeout fires we must add in the waiting dialog a custom message and a redirect button 
  */
+var timeout_dialog;
 function safe_security_timer(sec,msg,label,url,wait_dialog){
 	sec 	= defaultvalue(sec, 0);
 	wait_dialog    = defaultvalue(wait_dialog, null);
@@ -520,23 +521,68 @@ function safe_security_timer(sec,msg,label,url,wait_dialog){
 	}
 	return false;
 }
-
+var log_timeout_obj;
+var processing_log = '';
+var processing_log_timeout_obj;
+function fetchProcessingLog(url,log_timeout_data){
+    function onDataReceived(response){
+      //check if the data same as last request
+      if(processing_log.toString() == response.data.toString()){
+          if(timeout_dialog){
+              //stop get the log
+              clearTimeout(log_timeout_obj);
+              return;
+          }
+      }else{
+          //reset timer and update ui
+          clearTimeout(processing_log_timeout_obj);
+          processing_log_timeout_obj = safe_security_timer(log_timeout_data.sec,log_timeout_data.msg,log_timeout_data.label,log_timeout_data.url,log_timeout_data.wait_dialog);
+          processing_log = response.data
+          updateProcessingLog(response.data);
+      }
+      //get log every 5s
+      log_timeout_obj = setTimeout(function(){fetchProcessingLog(url,log_timeout_data)}, 10 * 1000);
+    }
+    $.ajax({
+      url:url,
+      type: 'GET',
+      dataType:'json',
+      async:true,
+      success:onDataReceived,
+      error:function(xhr, textStatus){
+          console.log('RX Error:' +  xhr.statusCode() + ' - ' + textStatus);
+          //re try if network error
+          log_timeout_obj = setTimeout(function(){fetchProcessingLog(url,log_timeout_data)}, 10 * 1000);
+          }
+      });
+  }
+function updateProcessingLog(data){
+    // Update log to ui
+    if( $("#processing_log_content").length && !timeout_dialog){
+        $('#processing_log_content').html(data);
+        $('#processing_log_content').animate({
+            scrollTop: $('#processing_log_content').get(0).scrollHeight}, 1000);
+    }else{
+        clearTimeout(log_timeout_obj);
+    }
+}
 /**
  * @function safe_wait
  * @param content (message show in the dialog)
  * @param type (spinning_wheel, or processing_bar ) 
  * @desc show a please wait dialog and block the ui 
  */
-function safe_wait(content,type,sec,msg,label,url){
+function safe_wait(content,type,sec,msg,label,url,log_url){
 	content 	= defaultvalue(content, 'Please wait...');
 	type 	= defaultvalue(type, 'spinning_wheel');
 	sec 	= defaultvalue(sec, 0);
 	msg 	= defaultvalue(msg, 'Timeout...');
 	label 	= defaultvalue(label, 'Ok');
 	url 	= defaultvalue(url, '');
+	log_url    = defaultvalue(log_url, '');
 	if(type == 'spinning_wheel'){
-		
 		var wait_dialog = $('<div><center><br><img src="/templates/base/images/icons/16x16/icon-loading.gif" style="vertical-align:middle;"> &nbsp;Please wait... <br><br><div id="content">' + content + "</div></center></div>").dialog({
+		    closeOnEscape: false,
 			autoOpen: true,
 			position: "center",
 			modal: true,
@@ -559,9 +605,53 @@ function safe_wait(content,type,sec,msg,label,url){
 		});
 		var security_timer = safe_security_timer(sec,msg,label,url,wait_dialog);
 		return wait_dialog;
+	}else if(type == 'processing_log'){
+	    var wait_dialog = $('<div><center><br><img src="/templates/base/images/icons/16x16/icon-loading.gif" style="vertical-align:middle;"> &nbsp;Please wait... <br><br><div id="content">' 
+	                        + content 
+	                        + '<div style="margin-top: 10px; margin-bottom: 10px;">'
+	                        +      '<div id="processing_log_content" style="text-align: left;width:auto;max-width:600px;height: 200px;overflow-x: auto;overflow-y: auto;">'
+	                        +      '</div>'
+	                        + '</div>'
+	                        + "</div></center></div>"
+	                            
+	    ).dialog({
+	        closeOnEscape: false,
+            autoOpen: true,
+            position: "center",
+            modal: true,
+            width: 'auto',
+            maxHeight: 600,
+            maxWidth: 600,
+            minWidth: 400,
+            draggable: false,
+            resizable: false,
+            dialogClass: 'msgbox',
+            open: function( event, ui ) {
+                $(this).closest(".ui-dialog").find(".ui-dialog-titlebar:first").hide();
+                $(this).closest(".ui-dialog").find(".ui-dialog-content:first").css('overflow', 'hidden');
+                //get the processing_log
+                var log_timeout_data = {};
+                log_timeout_data.sec = sec;
+                log_timeout_data.msg = msg;
+                log_timeout_data.label = label;
+                log_timeout_data.url = url;
+                log_timeout_data.wait_dialog = wait_dialog;
+                fetchProcessingLog(log_url, log_timeout_data);
+            },
+            close: function() {
+                //destory the dialog
+                if(security_timer) clearTimeout (security_timer);
+                $(this).dialog("destroy").remove();
+                clearTimeout(log_timeout_obj);
+            }
+        });
+	    //process log timeout
+	    processing_log_timeout_obj = safe_security_timer(sec,msg,label,url,wait_dialog);
+        return wait_dialog;
 	}else if(type == 'processing_bar'){
 		return $('<div><center><br><img src="/templates/base/images/icons/16x16/icon-loading.gif" style="vertical-align:middle;"> &nbsp;Please wait... <br><br><div id="safe_progress_bar"><span id="percent" style="width: 100%;"></span></div><br><div id="content">' + content + "</div></center></div>").dialog({
-			autoOpen: true,
+		    closeOnEscape: false,
+		    autoOpen: true,
 			position: "center",
 			modal: true,
 			width: 'auto',
