@@ -41,6 +41,8 @@ $lang['in_list'] = "The %s field contains an invalid option.";
 $lang['not_in_list'] = "The %s field contains an invalid data.";
 $lang['date_greater_than']		= "The %s field must contain a date greater than %s.";
 $lang['valid_sip_account']		= "The %s field must contain a valid SIP account.";
+$lang['validate_account_filter']		= "Invalid Account Filter Expression.";
+$lang['validate_user_agent_filter']		= "Invalid User Agent Filter Expression.";
 $lang['valid_ip_or_prefix']		= "The %s field must contain a valid IP or Subnetwork like '10.20.1.0/24'.";
 $lang['regex_required']			= "The %s field is required.";
 $lang['disabled']			= "The %s field cannot be modified.";
