@@ -65,6 +65,7 @@ class CI_Email
     var $_smtp_auth = FALSE;
     var $_replyto_flag = FALSE;
     var $_debug_msg = array();
+    var $_error_msg = array();
     var $_recipients = array();
     var $_cc_array = array();
     var $_bcc_array = array();
@@ -153,6 +154,7 @@ class CI_Email
         $this->_bcc_array = array();
         $this->_headers = array();
         $this->_debug_msg = array();
+        $this->_error_msg = array();
         $this->_set_header('User-Agent', $this->useragent);
         $this->_set_header('Date', $this->_set_date());
         if ($clear_attachments !== FALSE) {
@@ -569,6 +571,8 @@ class CI_Email
                 $this->_encoding = '7bit';
             }
         }
+        // WADAM - Force '7bit'
+        $this->_encoding = '7bit';
         if ($return == TRUE) {
             return $this->_encoding;
         }
@@ -1226,7 +1230,7 @@ class CI_Email
 
         case 'smtp':
             if (!$this->_send_with_smtp()) {
-                $this->_set_error_message('lang:email_send_failure_smtp');
+                //$this->_set_error_message('lang:email_send_failure_smtp');
                 return FALSE;
             }
             break;
@@ -1302,38 +1306,42 @@ class CI_Email
             $this->_set_error_message('lang:email_no_hostname');
             return FALSE;
         }
-        $this->_smtp_connect();
-        $this->_smtp_authenticate();
-        $this->_send_command('from', $this->clean_email($this->_headers['From']));
-        foreach ($this->_recipients as $val) {
-            $this->_send_command('to', $val);
-        }
-        if (count($this->_cc_array) > 0) {
-            foreach ($this->_cc_array as $val) {
-                if ($val != "") {
-                    $this->_send_command('to', $val);
+        if($this->_smtp_connect()){
+          if($this->_smtp_authenticate()){
+            $this->_send_command('from', $this->clean_email($this->_headers['From']));
+            foreach ($this->_recipients as $val) {
+                $this->_send_command('to', $val);
+            }
+            if (count($this->_cc_array) > 0) {
+                foreach ($this->_cc_array as $val) {
+                    if ($val != "") {
+                        $this->_send_command('to', $val);
+                    }
                 }
             }
-        }
-        if (count($this->_bcc_array) > 0) {
-            foreach ($this->_bcc_array as $val) {
-                if ($val != "") {
-                    $this->_send_command('to', $val);
+            if (count($this->_bcc_array) > 0) {
+                foreach ($this->_bcc_array as $val) {
+                    if ($val != "") {
+                        $this->_send_command('to', $val);
+                    }
                 }
             }
+            $this->_send_command('data');
+            // perform dot transformation on any lines that begin with a dot
+            $this->_send_data($this->_header_str . preg_replace('/^\./m', '..$1', $this->_finalbody));
+            $this->_send_data('.');
+            $reply = $this->_get_smtp_data();
+            $this->_set_error_message($reply);
+            $rc = TRUE;
+            if (strncmp($reply, '250', 3) != 0) {
+                $this->_set_error_message('lang:email_smtp_error', $reply);
+                $rc = FALSE;
+            }
+          }
+          $this->_send_command('quit');
+          return $rc;
         }
-        $this->_send_command('data');
-        // perform dot transformation on any lines that begin with a dot
-        $this->_send_data($this->_header_str . preg_replace('/^\./m', '..$1', $this->_finalbody));
-        $this->_send_data('.');
-        $reply = $this->_get_smtp_data();
-        $this->_set_error_message($reply);
-        if (strncmp($reply, '250', 3) != 0) {
-            $this->_set_error_message('lang:email_smtp_error', $reply);
-            return FALSE;
-        }
-        $this->_send_command('quit');
-        return TRUE;
+        return FALSE;
     }
     // --------------------------------------------------------------------
     
@@ -1350,7 +1358,7 @@ class CI_Email
         if ($this->smtp_crypto == 'ssl') $ssl = 'ssl://';
         $this->_smtp_connect = fsockopen($ssl . $this->smtp_host, $this->smtp_port, $errno, $errstr, $this->smtp_timeout);
         if (!is_resource($this->_smtp_connect)) {
-            $this->_set_error_message('lang:email_smtp_error', $errno . " " . $errstr);
+            $this->_set_error_message('lang:email_smtp_connect_error', $this->smtp_host.':'.$this->smtp_port . ' errno('. $errno . "," . $errstr .")");
             return FALSE;
         }
         $this->_set_error_message($this->_get_smtp_data());
@@ -1376,7 +1384,7 @@ class CI_Email
         switch ($cmd) {
         case 'hello':
             if ($this->_smtp_auth OR $this->_get_encoding() == '8bit') $this->_send_data('EHLO ' . $this->_get_hostname());
-            else $this->_send_data('HELO ' . $this->_get_hostname());
+            else  $this->_send_data('HELO ' . $this->_get_hostname());
             $resp = 250;
             break;
 
@@ -1409,6 +1417,8 @@ class CI_Email
         $this->_debug_msg[] = "<pre>" . $cmd . ": " . $reply . "</pre>";
         if (substr($reply, 0, 3) != $resp) {
             $this->_set_error_message('lang:email_smtp_error', $reply);
+            error_log('_send_command("'.$cmd.'") fail');
+            error_log('Expecting <'.$resp.'> Received <'.substr($reply, 0, 3).'>');
             return FALSE;
         }
         if ($cmd == 'quit') {
@@ -1541,6 +1551,10 @@ class CI_Email
      * @access	public
      * @return	string
      */
+    public function get_error()
+    {
+      return $this->_error_msg;
+    }
     public function print_debugger()
     {
         $msg = '';
@@ -1567,8 +1581,10 @@ class CI_Email
         $CI->lang->load('email');
         if (substr($msg, 0, 5) != 'lang:' || FALSE === ($line = $CI->lang->line(substr($msg, 5)))) {
             $this->_debug_msg[] = str_replace('%s', $val, $msg) . "<br />";
+            $this->_error_msg[] = str_replace('%s', $val, $msg);
         } else {
             $this->_debug_msg[] = str_replace('%s', $val, $line) . "<br />";
+            $this->_error_msg[] = str_replace('%s', $val, $line);
         }
     }
     // --------------------------------------------------------------------
