@@ -136,43 +136,47 @@ class CI_Upload
             // errors will already be set by validate_upload_path() so just return FALSE
             return FALSE;
         }
-        // Was the file able to be uploaded? If not, determine the reason why.
-        if (!is_uploaded_file($_FILES[$field]['tmp_name'])) {
-            $error = (!isset($_FILES[$field]['error'])) ? 4 : $_FILES[$field]['error'];
-            switch ($error) {
-            case 1: // UPLOAD_ERR_INI_SIZE
-                $this->set_error('upload_file_exceeds_limit');
-                break;
-
-            case 2: // UPLOAD_ERR_FORM_SIZE
-                $this->set_error('upload_file_exceeds_form_limit');
-                break;
-
-            case 3: // UPLOAD_ERR_PARTIAL
-                $this->set_error('upload_file_partial');
-                break;
-
-            case 4: // UPLOAD_ERR_NO_FILE
-                $this->set_error('upload_no_file_selected');
-                break;
-
-            case 6: // UPLOAD_ERR_NO_TMP_DIR
-                $this->set_error('upload_no_temp_directory');
-                break;
-
-            case 7: // UPLOAD_ERR_CANT_WRITE
-                $this->set_error('upload_unable_to_write_file');
-                break;
-
-            case 8: // UPLOAD_ERR_EXTENSION
-                $this->set_error('upload_stopped_by_extension');
-                break;
-
-            default:
-                $this->set_error('upload_no_file_selected');
-                break;
+        if( $_FILES[$field]['from'] == 'PUT'){
+            //passby put upload is_uploaded_file will return false is not post upload
+        }else{
+            // Was the file able to be uploaded? If not, determine the reason why.
+            if (!is_uploaded_file($_FILES[$field]['tmp_name'])) {
+                $error = (!isset($_FILES[$field]['error'])) ? 4 : $_FILES[$field]['error'];
+                switch ($error) {
+                case 1: // UPLOAD_ERR_INI_SIZE
+                    $this->set_error('upload_file_exceeds_limit');
+                    break;
+    
+                case 2: // UPLOAD_ERR_FORM_SIZE
+                    $this->set_error('upload_file_exceeds_form_limit');
+                    break;
+    
+                case 3: // UPLOAD_ERR_PARTIAL
+                    $this->set_error('upload_file_partial');
+                    break;
+    
+                case 4: // UPLOAD_ERR_NO_FILE
+                    $this->set_error('upload_no_file_selected');
+                    break;
+    
+                case 6: // UPLOAD_ERR_NO_TMP_DIR
+                    $this->set_error('upload_no_temp_directory');
+                    break;
+    
+                case 7: // UPLOAD_ERR_CANT_WRITE
+                    $this->set_error('upload_unable_to_write_file');
+                    break;
+    
+                case 8: // UPLOAD_ERR_EXTENSION
+                    $this->set_error('upload_stopped_by_extension');
+                    break;
+    
+                default:
+                    $this->set_error('upload_no_file_selected');
+                    break;
+                }
+                return FALSE;
             }
-            return FALSE;
         }
         // Set the uploaded data as class variables
         $this->file_temp = $_FILES[$field]['tmp_name'];
@@ -530,8 +534,9 @@ class CI_Upload
                 return FALSE;
             }
         }
-        if ($ignore_mime === TRUE) {
-            return TRUE;
+        /* mime type can be empty, so skip mime check */
+        if ($ignore_mime === TRUE || !$this->file_type) {
+          return TRUE;
         }
         $mime = $this->mimes_types($ext);
         if (is_array($mime)) {
