@@ -190,7 +190,7 @@ class Sng_transcoding_config_class extends Safe_configurable_object_class
                     'gateway',
                     'udp_end',
                     'vqe/acoustic_echo',
-                    'vqe/rx_adaptative_noise_reduction',
+                    'vqe/rx_adaptive_noise_reduction',
                     'vqe/rx_automatic_level_control',
                     'vqe/rx_automatic_level_control_target_dbm0',
                     'vqe/tx_automatic_level_control',
@@ -235,15 +235,15 @@ class Sng_transcoding_config_class extends Safe_configurable_object_class
                 '<font color="red">Note that enabling this feature will reduce your call capacity in about 35%.</font>')
             );
 
-        $this->add_enum_field('vqe/rx_adaptative_noise_reduction', 'Adaptative Noise Reduction', 'dropdown', '0', $this->enable_disable_enum(false));
-        $this->set_field_help('vqe/rx_adaptative_noise_reduction',
+        $this->add_enum_field('vqe/rx_adaptive_noise_reduction', 'Adaptive Noise Reduction', 'dropdown', '0', $this->enable_disable_enum(false));
+        $this->set_field_help('vqe/rx_adaptive_noise_reduction',
             array(
                 'Enable Adaptive Noise Reduction for all media sessions.',
                 'This removes the noise present while leaving voice intact.',
                 '<font color="red">Note that enabling this feature will reduce your call capacity in about 35%.</font>')
             );
 
-        $this->add_enum_field('vqe/rx_automatic_level_control', 'Adaptative Level Control (RX)', 'dropdown', '0', $this->enable_disable_enum(false));
+        $this->add_enum_field('vqe/rx_automatic_level_control', 'Automatic Level Control (RX)', 'dropdown', '0', $this->enable_disable_enum(false));
         $this->set_field_help('vqe/rx_automatic_level_control',
             array(
                 'Enable RX Automatic Level Control for all media sessions.',
@@ -254,7 +254,7 @@ class Sng_transcoding_config_class extends Safe_configurable_object_class
         $this->set_field_rules('vqe/rx_automatic_level_control_target_dbm0', 'required[vqe/rx_automatic_level_control]|integer|greater_or_equal[-42]|less_or_equal[-6]');
         $this->composite_layout('vqe/rx_automatic_level_control', array('vqe/rx_automatic_level_control_target_dbm0'));
 
-        $this->add_enum_field('vqe/tx_automatic_level_control', 'Adaptative Level Control (TX)', 'dropdown', '0', $this->enable_disable_enum(false));
+        $this->add_enum_field('vqe/tx_automatic_level_control', 'Automatic Level Control (TX)', 'dropdown', '0', $this->enable_disable_enum(false));
         $this->set_field_help('vqe/tx_automatic_level_control',
             array(
                 'Enable TX Automatic Level Control for all media sessions.',
