@@ -40,7 +40,7 @@ class Sng_transcoding_module_class extends Safe_configurable_object_class
                 'ext_ip_address' => '',
                 'vlan_id' => '',
                 'vqe/acoustic_echo' => '0',
-                'vqe/rx_adaptative_noise_reduction' => '0',
+                'vqe/rx_adaptive_noise_reduction' => '0',
                 'vqe/rx_automatic_level_control' => '0',
                 'vqe/rx_automatic_level_control_target_dbm0' => -21,
                 'vqe/tx_automatic_level_control' => '0',
@@ -102,16 +102,16 @@ class Sng_transcoding_module_class extends Safe_configurable_object_class
                 '<font color="red">Note that enabling this feature will reduce your call capacity in about 35%.</font>')
             );
 
-        $this->add_enum_field('vqe/rx_adaptative_noise_reduction', 'Adaptative Noise Reduction', 'dropdown', $network_cfg['vqe/rx_adaptative_noise_reduction'], $this->enable_disable_enum(false));
-        $this->set_field_disabled('vqe/rx_adaptative_noise_reduction', 'disabled');
-        $this->set_field_help('vqe/rx_adaptative_noise_reduction',
+        $this->add_enum_field('vqe/rx_adaptive_noise_reduction', 'Adaptive Noise Reduction', 'dropdown', $network_cfg['vqe/rx_adaptive_noise_reduction'], $this->enable_disable_enum(false));
+        $this->set_field_disabled('vqe/rx_adaptive_noise_reduction', 'disabled');
+        $this->set_field_help('vqe/rx_adaptive_noise_reduction',
             array(
                 'Enable Adaptive Noise Reduction for all media sessions.',
                 'This removes the noise present while leaving voice intact.',
                 '<font color="red">Note that enabling this feature will reduce your call capacity in about 35%.</font>')
             );
 
-        $this->add_enum_field('vqe/rx_automatic_level_control', 'Adaptative Level Control (RX)', 'dropdown', $network_cfg['vqe/rx_automatic_level_control'], $this->enable_disable_enum(false));
+        $this->add_enum_field('vqe/rx_automatic_level_control', 'Automatic Level Control (RX)', 'dropdown', $network_cfg['vqe/rx_automatic_level_control'], $this->enable_disable_enum(false));
         $this->set_field_disabled('vqe/rx_automatic_level_control', 'disabled');
         $this->set_field_help('vqe/rx_automatic_level_control',
             array(
@@ -124,7 +124,7 @@ class Sng_transcoding_module_class extends Safe_configurable_object_class
         $this->set_field_disabled('vqe/rx_automatic_level_control_target_dbm0', 'disabled');
         $this->composite_layout('vqe/rx_automatic_level_control', array('vqe/rx_automatic_level_control_target_dbm0'));
 
-        $this->add_enum_field('vqe/tx_automatic_level_control', 'Adaptative Level Control (TX)', 'dropdown', $network_cfg['vqe/tx_automatic_level_control'], $this->enable_disable_enum(false));
+        $this->add_enum_field('vqe/tx_automatic_level_control', 'Automatic Level Control (TX)', 'dropdown', $network_cfg['vqe/tx_automatic_level_control'], $this->enable_disable_enum(false));
         $this->set_field_help('vqe/tx_automatic_level_control',
             array(
                 'Enable TX Automatic Level Control for all media sessions.',
