@@ -51,7 +51,7 @@ class Sng_control_panel extends Safe_CI_Controller
     {
         // Set the basic data
         $data['page_title'] = 'Control Panel';
-        $data['page_summary'] = 'This page allows controlling Application hardware and software.';
+        $data['page_summary'] = 'This page allows controlling application hardware and software.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-register.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-register.png';
         $data['errors'] = array();
@@ -108,7 +108,7 @@ class Sng_control_panel extends Safe_CI_Controller
     {
         // Set the basic data
         $data['page_title'] = 'Control Panel';
-        $data['page_summary'] = 'This page allows controlling Application hardware and software.';
+        $data['page_summary'] = 'This page allows controlling application hardware and software.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-register.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-register.png';
         $data['errors'] = array();
@@ -350,7 +350,7 @@ class Sng_control_panel extends Safe_CI_Controller
         $data['setting']['title'] = 'Resetting '.$service->description();
         $data['setting']['sec'] = '60';
         $data['setting']['msg'] = 'Ooops ! Server time out...';
-        $data['setting']['lable'] = 'Back';
+        $data['setting']['label'] = 'Back';
         $data['setting']['url'] = base_url('sng_control_panel');
         echo json_encode($data);
     }
@@ -404,7 +404,7 @@ class Sng_control_panel extends Safe_CI_Controller
         $data['table'] = $table->generate();
         // Set the basic data
         $data['page_title'] = 'Control Panel';
-        $data['page_summary'] = 'This page allows controlling Application hardware and software.';
+        $data['page_summary'] = 'This page allows controlling application hardware and software.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-register.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-register.png';
         $data['errors'] = array();
@@ -425,7 +425,7 @@ class Sng_control_panel extends Safe_CI_Controller
         $data['setting']['title'] = 'Stopping '.$service->description() ;
         $data['setting']['sec'] = '60';
         $data['setting']['msg'] = 'Ooops ! Server time out...';
-        $data['setting']['lable'] = 'Back';
+        $data['setting']['label'] = 'Back';
         $data['setting']['url'] = base_url('sng_control_panel');
         echo json_encode($data);
     }
@@ -493,7 +493,7 @@ class Sng_control_panel extends Safe_CI_Controller
         $data['table'] = $table->generate();
         // Set the basic data
         $data['page_title'] = 'Control Panel';
-        $data['page_summary'] = 'This page allows controlling Application hardware and software.';
+        $data['page_summary'] = 'This page allows controlling application hardware and software.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-register.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-register.png';
         $data['errors'] = array();
